<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="名称">
              <el-input clearable placeholder="请输入名称" v-model="querys[0].value" />
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label=" 类型">
              <el-select clearable filterable style="width:100%" v-model="querys[1].value" placeholder="请选择 类型">
                <el-option v-for="item in dtypeSelectOptions" :key="item.code" :label="item.name"
                  :value="item.code"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="7">
            <el-form-item label="接收时间">
              <el-date-picker v-model="querys[2].value" type="datetimerange" style="width:100%"
                popper-class="dataTime-style" value-format="yyyy-MM-dd HH:mm:ss" range-separator="至"
                start-placeholder="开始日期" end-placeholder="结束日期"></el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete" type="danger"
            style="margin-left: 10px">删除
          </el-button>
        </el-popconfirm>
      </div>
      <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column fixed type="index" width="55" label="序号"></el-table-column>

        <el-table-column fixed prop="dtypeName" label="点位类型" show-overflow-tooltip></el-table-column>

        <el-table-column fixed prop="name" label="名称" show-overflow-tooltip></el-table-column>
        <el-table-column fixed prop="areaName" label="所在区域" show-overflow-tooltip></el-table-column>

        <el-table-column fixed prop="latitude" label="纬度" show-overflow-tooltip></el-table-column>

        <el-table-column fixed prop="longitude" label="经度" show-overflow-tooltip></el-table-column>

        <el-table-column fixed prop="location" label="定位信息" show-overflow-tooltip></el-table-column>

        <el-table-column fixed sortable prop="receiveTime" label="接收时间" show-overflow-tooltip></el-table-column>

        <el-table-column fixed sortable prop="updateTime" label="修改时间" show-overflow-tooltip></el-table-column>
      </el-table>
      <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" :current-page="queryParam.pageBean.page"
        :page-sizes="[20, 30, 40, 50]" :page-size="queryParam.pageBean.pageSize"
        layout="total, sizes, prev, pager, next, jumper" :total="total"></el-pagination>
    </div>
    <CmgtBasePositionFormDialog :equipmentList="equipmentList" :userList="userList" ref="formModal">
    </CmgtBasePositionFormDialog>
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import dictContracts from '@/components/dict/DictSelectUtils.js'
import CommonApi from '@/views/Manage/CommonApi.js'
import CmgtBasePositionApi from '@/views/Manage/base/api/CmgtBasePositionApi'
import CmgtBasePositionFormDialog from '@/views/Manage/base/components/CmgtBasePositionFormDialog'
import equipmentManage from '@/api/device/equipmentManage.js'
import teamMemberManage from '@/api/manager/duty/teamMemberManage.js'

export default {
  name: 'CmgtBasePositionManage',
  components: {
    CmgtBasePositionFormDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/manager/cmgtBasePosition/delete'
      },
      dtypeSelectOptions: [],
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'name_',
          relation: 'AND',
          value: ''
        },

        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'dtype_',
          relation: 'AND',
          value: ''
        },

        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'receive_time_',
          relation: 'AND',
          value: ''
        }
      ],
      StshowFormDias: false,
      fuelTypes: [],
      equipmentList: [], // 关联区域列表
      userList: [], // 关联人员列表
      dtypeSelectOptions: []
    }
  },
  created() {
    this.getEquipmentList()

    this.getUserList()
    CommonApi.loadSelectOptions(
      { name: 'cmgtBasePositionManagerImpl.getAllPositionType' },
      res => {
        this.dtypeSelectOptions = res
      }
    )
  },
  mounted() {
  },
  methods: {
    // 获取关联区域列表
    getEquipmentList() {
      equipmentManage.loadAreaTree({ id: '0' }, res => {
        this.equipmentList = res.value
      })
    },

    // 获取关联人员列表

    getUserList() {
      teamMemberManage.pageQuery({
        pageBean: {
          pageSize: -1,
          page: 1
        },
        params: {},
        querys: []
      }).then(res => {
        this.userList = res.data.rows
      })
    },
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.sorter = [
        {
          direction: 'DESC',
          property: 'create_time_'
        }
      ]
      this.queryParam.querys = []

      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      CmgtBasePositionApi.loadCmgtBasePosition(this.queryParam, res => {
        //console.log(res, 'res')
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    },
    // 修改
    handleUpdate(row) {
      console.log(row.id)
      this.$refs.formModal.Update(row)
    },
    // 关联设备
    // handleClick(item) {
    //   console.log(item.id)
    //   this.StshowFormDias = true
    // },
    closeStshowForm() {
      this.StshowFormDias = false
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
